@@ -1,7 +1,7 @@
 package Text::Table::Any;
 
-our $DATE = '2016-09-06'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-10-19'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 #IFUNBUILT
 # # use 5.010001;
@@ -26,6 +26,18 @@ sub table {
         require Text::Table::Tiny;
         return Text::Table::Tiny::table(
             rows => $rows, header_row => $header_row) . "\n";
+    } elsif ($backend eq 'Text::Table::TinyColor') {
+        require Text::Table::TinyColor;
+        return Text::Table::TinyColor::table(
+            rows => $rows, header_row => $header_row) . "\n";
+    } elsif ($backend eq 'Text::Table::TinyColorWide') {
+        require Text::Table::TinyColorWide;
+        return Text::Table::TinyColorWide::table(
+            rows => $rows, header_row => $header_row) . "\n";
+    } elsif ($backend eq 'Text::Table::TinyWide') {
+        require Text::Table::TinyWide;
+        return Text::Table::TinyWide::table(
+            rows => $rows, header_row => $header_row) . "\n";
     } elsif ($backend eq 'Text::Table::Org') {
         require Text::Table::Org;
         return Text::Table::Org::table(
@@ -112,7 +124,7 @@ Text::Table::Any - Generate text table using one of several backends
 
 =head1 VERSION
 
-This document describes version 0.04 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2016-09-06.
+This document describes version 0.05 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2016-10-19.
 
 =head1 SYNOPSIS
 
@@ -236,6 +248,12 @@ Optional. Pick a backend module. Available backends:
 
 =item * Text::Table::Tiny
 
+=item * Text::Table::TinyColor
+
+=item * Text::Table::TinyColorWide
+
+=item * Text::Table::TinyWide
+
 =item * Text::Table::Org
 
 =item * Text::Table::CSV
